require 'nokogiri'
require 'slim'

require_relative 'action_group'

module Knartform
    class Knart
        attr_accessor :document
        attr_accessor :type
        HTML_OPTIONS = {}.freeze

        def initialize(file)
            load(file)
    end

        def load(file)
            self.document = nil
            self.type = nil
            begin
                puts "Loading #{file.path}..."
                self.document = Nokogiri::XML(file) { |config| config.options = Nokogiri::XML::ParseOptions::STRICT }
                self.type = document.xpath('//knart:knowledgeDocument/knart:metadata/knart:artifactType', knart: 'urn:hl7-org:knowledgeartifact:r1').first['value']
                puts "Detected 'artifactType' of '#{type}'."
            rescue Nokogiri::XML::SyntaxError => e
                puts "Issue in KNART document: #{e}"
            end
        end

        def loaded?
            !document.nil?
        end

        def to_html(options = {})
            opts = HTML_OPTIONS.merge(options)
            html = nil
            case type
            when 'Documentation Template'
                path = File.expand_path('../../views/documentation_template.slim', __FILE__)
                html = Slim::Template.new(path, pretty: true, disable_escape: true).render(self)
            else
                path = File.expand_path('../../views/unsupported.slim', __FILE__)
                html = Slim::Template.new(path, pretty: true).render(self)
            end
            html
        end

        def first_attribute(nodes, name)
            nodes.empty? ? '' : nodes.first[name]
        end

        def dummy_edit_and_delete
            path = File.expand_path('../../views/dummy_edit_and_delete.slim', __FILE__)
            html = Slim::Template.new(path, pretty: true).render(self)
        end

        def dummy_add_button
            path = File.expand_path('../../views/dummy_add_button.slim', __FILE__)
            html = Slim::Template.new(path, pretty: true).render(self)
        end

        def dummy_edit_button
            path = File.expand_path('../../views/dummy_edit_button.slim', __FILE__)
            html = Slim::Template.new(path, pretty: true).render(self)
          end

        def dummy_drag_control
            path = File.expand_path('../../views/dummy_drag_control.slim', __FILE__)
            html = Slim::Template.new(path, pretty: true).render(self)
            end
    end
end
